/*
lkmonitor (Linux Kernel Monitor)

Application for monitoring and tuning a Linux kernel.

Copyright (C) 2005,2006  Fernando Apesteguía

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

#include <string.h>
#include <stdio.h>
#include "lininfo.h"
#include <sys/types.h>
#include <dirent.h>

#include <glib.h>
#include <pthread.h>
#include <gtk/gtk.h>

extern pthread_t thread_id;//Id of collector thread.


void set_tooltiptext(GtkWidget *object,gchar *str)
{
	g_assert(object!=NULL && str!=NULL);
	
	GtkTooltips *gtt;
	
	gtt=gtk_tooltips_new();
	gtk_tooltips_set_tip(gtt,object,str,NULL);
	
}

/*! Deletes blanks from the begining of string
* \param str String to delete blanks from
* \return Trimed String
*/
char *
trim (char *str)
{
  return (str + strspn (str, " "));
}				

/*! Deletes blanks from the end of string
* \param str String to delete blanks from
* \return Trimed String
*/
char *
rtrim(char* str)
{
	g_assert(str!=NULL);
	
	char* p;
	if((p=rindex(str,' '))==NULL)
		return(str);
	while(p>str){
		if(*p==' '){
			*p='\0';
			p--;
		}
		else return(str);
	}
	return(str);//For gcc warning	
}


/*! Delete initial lines form string
* \param contents String that contents text
* \param num_lines Number of lines to leave out
* \return 0 on success
*/
int
skip_lines (char* contents, int num_lines)
{
  g_assert(contents!=NULL && num_lines>=0);
	
  int i, c;

  for (i = 0; i < num_lines; c++)
    if (*contents=='\n'){
      i++;
	}else{
       contents++;
	}

  return (0);
}

/*! Main parse function.
* This function actually parses the contents of procfs files and tokenize
* elements to offer clean data.
* \param pattern sscanf pattern format to make parsing
* \param member Field struct to fill with parsed data
* \param contents Contents of the file to be analyzed
*/
void
find_data_for (char* pattern,char* member, const char* contents)
{	

	g_assert(pattern!=NULL && member!=NULL && contents!=NULL);
	
	char p[25];
	char* line;
	
	sscanf(pattern,"%[^\t:]",p);
	//p has the name of the attribute (model, model name...)
	strcpy(p,rtrim(p));
	if((line=strstr(contents,p))==NULL){
		strcpy(member,"Unknown");
		return;
	}//Position in the correct line
	
	sscanf(line, pattern,member);
	
}				///End find_data_for

/*! Stops collector thread and runs outside event loop
*/
void lkmonitor_exit()
{
  	if(pthread_cancel(thread_id)!=0)
	  g_warning("Can't cancel collector thread!");
	
	gtk_main_quit();
}
